@@ -367,9 +367,9 @@ class ServerlessClusterFromSnapshotProps:
         :stability: deprecated
         '''
         if isinstance(scaling, dict):
-            scaling = ServerlessScalingOptions(**scaling)
+            scaling = aws_cdk.aws_rds.ServerlessScalingOptions(**scaling)
         if isinstance(vpc_subnets, dict):
-            vpc_subnets = SubnetSelection(**vpc_subnets)
+            vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
         if __debug__:
             type_hints = typing.get_type_hints(ServerlessClusterFromSnapshotProps.__init__)
             check_type(argname="argument engine", value=engine, expected_type=type_hints["engine"])
